/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.gradle.plugins.target.platform.internal.util;

import org.gradle.api.Project;
import org.gradle.api.Task;
import org.gradle.api.execution.TaskExecutionGraph;
import org.gradle.api.invocation.Gradle;
import org.gradle.api.specs.Spec;
import org.gradle.api.tasks.TaskContainer;

/**
 * @author Andrea Di Giorgi
 */
public class SkipIfExecutingParentTaskSpec implements Spec<Task> {

	@Override
	public boolean isSatisfiedBy(Task task) {
		Project project = task.getProject();

		Gradle gradle = project.getGradle();

		TaskExecutionGraph taskExecutionGraph = gradle.getTaskGraph();

		Project parentProject = project;

		while ((parentProject = parentProject.getParent()) != null) {
			TaskContainer parentProjectTaskContainer = parentProject.getTasks();

			Task parentProjectTask = parentProjectTaskContainer.findByName(
				task.getName());

			if ((parentProjectTask != null) &&
				taskExecutionGraph.hasTask(parentProjectTask)) {

				return false;
			}
		}

		return true;
	}

}