/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.gradle.plugins.target.platform.internal.util;

import java.util.List;

import org.gradle.api.Action;
import org.gradle.api.Project;
import org.gradle.api.artifacts.Configuration;
import org.gradle.api.artifacts.ConfigurationContainer;
import org.gradle.api.artifacts.Dependency;
import org.gradle.api.artifacts.DependencySet;
import org.gradle.api.artifacts.dsl.DependencyHandler;

/**
 * @author Gregory Amerson
 */
public class TargetPlatformPluginUtil {

	public static void configureTargetPlatform(
		Project project, List<String> configurationNames,
		final Configuration targetPlatformBomsConfiguration) {

		ConfigurationContainer configurationContainer =
			project.getConfigurations();

		final DependencyHandler dependencyHandler = project.getDependencies();

		configurationContainer.all(
			new Action<Configuration>() {

				@Override
				public void execute(Configuration configuration) {
					String name = configuration.getName();

					if (!configurationNames.contains(name)) {
						return;
					}

					if (name.equals("frontendCSSCommon") ||
						name.equals("originalModule") ||
						name.equals("parentThemes") ||
						name.equals("portalCommonCSS") ||
						name.equals("providedModules")) {

						configuration.setTransitive(true);
					}

					DependencySet dependencySet =
						targetPlatformBomsConfiguration.getDependencies();

					dependencySet.all(
						new Action<Dependency>() {

							@Override
							public void execute(Dependency dependency) {
								StringBuilder sb = new StringBuilder();

								sb.append(dependency.getGroup());
								sb.append(':');
								sb.append(dependency.getName());
								sb.append(':');
								sb.append(dependency.getVersion());

								Dependency platformDependency =
									dependencyHandler.platform(sb.toString());

								dependencyHandler.add(
									configuration.getName(),
									platformDependency);
							}

						});
				}

			});
	}

}